@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/ETMCalendar>
 
 #include <QDate>
 #include <QFrame>
