@@ -9,7 +9,7 @@
 
 #pragma once
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/ETMCalendar>
 #include <KontactInterface/Summary>
 
 class KOrganizerPlugin;
