@@ -51,9 +51,7 @@ TodoPlugin::TodoPlugin(KontactInterface::Core *core, const QVariantList &)
     mUniqueAppWatcher = new KontactInterface::UniqueAppWatcher(new KontactInterface::UniqueAppHandlerFactory<KOrganizerUniqueAppHandler>(), this);
 }
 
-TodoPlugin::~TodoPlugin()
-{
-}
+TodoPlugin::~TodoPlugin() = default;
 
 KontactInterface::Summary *TodoPlugin::createSummaryWidget(QWidget *parent)
 {
@@ -176,15 +174,14 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
                 const QUrlQuery query(url.query());
                 if (!query.queryItemValue(QStringLiteral("item")).isEmpty()
                     && query.queryItemValue(QStringLiteral("type")) == QStringLiteral("message/rfc822")) {
-                    Akonadi::ItemFetchJob *job =
-                        new Akonadi::ItemFetchJob(Akonadi::Item(static_cast<qint64>(query.queryItemValue(QStringLiteral("item")).toLongLong())));
+                    auto job = new Akonadi::ItemFetchJob(Akonadi::Item(static_cast<qint64>(query.queryItemValue(QStringLiteral("item")).toLongLong())));
                     job->fetchScope().fetchAllAttributes();
                     job->fetchScope().fetchFullPayload(true);
                     connect(job, &KJob::result, this, [this, url](KJob *job) {
                         if (job->error()) {
                             return;
                         }
-                        Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+                        auto fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
                         const Akonadi::Item::List items = fetchJob->items();
                         for (const Akonadi::Item &item : items) {
                             if (item.mimeType() == QStringLiteral("message/rfc822")) {
